Learn R Programming

drc (version 4.0-0)

AR: Asymptotic regression model

Description

Providing the mean function and the corresponding self starter function for the asymptotic regression model.

Usage

AR.2(fixed = c(NA, NA), names = c("d", "e"), ...)

AR.3(fixed = c(NA, NA, NA), names = c("c", "d", "e"), ...)

Arguments

Value

A list of class drcMean, containing the mean function, the self starter function, the parameter names and other components such as derivatives and a function for calculating ED values.

Details

The asymptotic regression model is a three-parameter model with mean function:

$$ f(x) = c + (d-c)(1-\exp(-x/e))$$

The parameter \(c\) is the lower limit (at \(x=0\)), the parameter \(d\) is the upper limit and the parameter \(e>0\) is determining the steepness of the increase as \(x\).

See Also

A very similar, but monotonously decreasing model is the exponential decay model: EXD.2 and EXD.3.

Examples

Run this code

## First model
met.as.m1<-drm(gain ~ dose, product, data = methionine, fct = AR.3(), 
pmodels = list(~1, ~factor(product), ~factor(product)))
plot(met.as.m1, log = "", ylim = c(1450, 1800))
summary(met.as.m1)

## Calculating bioefficacy: approach 1
coef(met.as.m1)[5] / coef(met.as.m1)[4] * 100

## Calculating bioefficacy: approach 2
EDcomp(met.as.m1, c(50,50))

## Simplified models
met.as.m2<-drm(gain ~ dose, product, data = methionine, fct = AR.3(), 
pmodels = list(~1, ~1, ~factor(product)))
anova(met.as.m2, met.as.m1)  # simplification not possible

met.as.m3 <- drm(gain ~ dose, product, data = methionine, fct = AR.3(), 
pmodels = list(~1, ~factor(product), ~1))
anova(met.as.m3, met.as.m1)  # simplification not possible

Run the code above in your browser using DataLab