The model function for inverse u-shaped hormetic patterns is
$$ f(x) = c + \frac{d-c+f \exp(-1/x^{\alpha})}{1+\exp(b(\log(x)-\log(e)))}$$,
which is a five-parameter model. It is a modification of the four-parameter log-logistic curve
to take hormesis into account.
The parameters have the following interpretations
\(b\): Not direct interpretation
\(c\): Lower horizontal asymptote
\(d\): Upper horizontal asymptote
\(e\): Not direct interpretation
\(f\): Size of the hormesis effect: the larger the value the larger is the hormesis effect. \(f=0\)
corresponds to no hormesis effect and the resulting model is the four-parameter log-logistic model.
This parameter should be positive in order for the model to make sense.
The model function for U-shaped hormetic patterns is
$$ f(x) = d - \frac{d-c+f \exp(-1/x^{\alpha})}{1+\exp(b(\log(x)-\log(e)))}$$
This model also simplifies to the four-parameter log-logistic model in case \(f=0\) (in a slightly
different parameterization as compared to the one used in LL.4).
The models denoted a,b,c are obtained by fixing the alpha parameter at 1, 0.5 and 0.25, respectively.