Skip to contents

S3 generic function that dispatches to the appropriate method for estimating effective concentrations (EC) or effective doses (ED) at specified response levels. For objects of class drc, the default method ED.drc is called.

Usage

ED(object, ...)

Arguments

object

an object of class drc.

...

additional arguments passed to the method.

Value

See ED.drc for details on the return value.

See also

ED.drc for the default method, EDcomp for estimating differences and ratios of ED

Author

Christian Ritz