Learn R Programming

drc (version 4.0-0)

LL.4: The four-parameter log-logistic function

Description

'LL.4' and 'LL2.4' provide the four-parameter log-logistic function, self starter function, names of the parameters and, optionally, first and second derivatives for a faster estimation.

Usage

LL.4(fixed = c(NA, NA, NA, NA), names = c("b", "c", "d", "e"), ...)

l4(fixed = c(NA, NA, NA, NA), names = c("b", "c", "d", "e"), ...) LL2.4(fixed = c(NA, NA, NA, NA), names = c("b", "c", "d", "e"), ...)

Value

See llogistic.

Arguments

fixed

numeric vector. Specifies which parameters are fixed and at what value they are fixed. NAs for parameter that are not fixed.

names

a vector of character strings giving the names of the parameters. The default is reasonable.

...

Additional arguments (see llogistic).

Author

Christian Ritz and Jens C. Streibig

Details

The four-parameter log-logistic function is given by the expression $$ f(x) = c + \frac{d-c}{1+\exp(b(\log(x)-\log(e)))}$$

or in another parameterisation (converting the term \(\log(e)\) into a parameter) $$ f(x) = c + \frac{d-c}{1+\exp(b(\log(x)-\tilde{e}))}$$

The function is symmetric about the inflection point (\(e\)).

References

Seber, G. A. F. and Wild, C. J (1989) Nonlinear Regression, New York: Wiley and Sons (p. 330).

Ritz, C (2010) Towards a unified approach to dose-response modeling in ecotoxicology, Environ Toxicol Chem 29, 220--229, https://doi.org/10.1002/etc.7

See Also

Setting \(c=0\) yields LL.3. See also LL.5.

Examples

Run this code

spinach.m1 <- drm(SLOPE ~ DOSE, CURVE, data = spinach, fct = LL.4())
spinach.m1

Run the code above in your browser using DataLab