Skip to contents

A two-parameter log-logistic model where the lower limit is fixed at 0 and the upper limit is fixed at a specified value (default 1). The estimated parameters are the slope b and the log(ED50) e.

Usage

LL2.2(upper = 1, fixed = c(NA, NA), names = c("b", "e"), ...)

Arguments

upper

numeric value giving the fixed upper limit. Defaults to 1.

fixed

numeric vector of length 2. Specifies which parameters are fixed and at what value. Use NA for parameters that should be estimated.

names

character vector of length 2 giving the names of the parameters b and e.

...

additional arguments passed to llogistic2.

Value

A list of class "llogistic" with the nonlinear function, self-starter, and related components.

See also

Examples

earthworms.m1 <- drm(number/total ~ dose, weights = total,
  data = earthworms, fct = LL2.2(), type = "binomial")