Skip to contents

A three-parameter log-logistic model where the upper limit is fixed at a specified value (default 1). The estimated parameters are the slope b, the lower limit c, and the log(ED50) e.

Usage

LL2.3u(upper = 1, fixed = c(NA, NA, NA), names = c("b", "c", "e"), ...)

Arguments

upper

numeric value giving the fixed upper limit. Defaults to 1.

fixed

numeric vector of length 3. Specifies which parameters are fixed and at what value. Use NA for parameters that should be estimated.

names

character vector of length 3 giving the names of the parameters b, c, and e.

...

additional arguments passed to llogistic2.

Value

A list of class "llogistic" with the nonlinear function, self-starter, and related components.

See also