Skip to contents

A four-parameter log-logistic model where the ED50 is parameterised on the log scale. The asymmetry parameter f is fixed at 1. The estimated parameters are the slope b, the lower limit c, the upper limit d, and the log(ED50) e.

Usage

LL2.4(fixed = c(NA, NA, NA, NA), names = c("b", "c", "d", "e"), ...)

Arguments

fixed

numeric vector of length 4. Specifies which parameters are fixed and at what value. Use NA for parameters that should be estimated.

names

character vector of length 4 giving the names of the parameters b, c, d, and e.

...

additional arguments passed to llogistic2.

Value

A list of class "llogistic" with the nonlinear function, self-starter, and related components.

See also

Examples

spinach.m1 <- drm(SLOPE ~ DOSE, CURVE, data = spinach, fct = LL2.4())