Skip to contents

A five-parameter generalised log-logistic model where the ED50 is parameterised on the log scale. All five parameters (b, c, d, e, f) are estimated.

Usage

LL2.5(fixed = c(NA, NA, NA, NA, NA), names = c("b", "c", "d", "e", "f"), ...)

Arguments

fixed

numeric vector of length 5. Specifies which parameters are fixed and at what value. Use NA for parameters that should be estimated.

names

character vector of length 5 giving the names of the parameters b, c, d, e, and f.

...

additional arguments passed to llogistic2.

Value

A list of class "llogistic" with the nonlinear function, self-starter, and related components.

See also

Examples

ryegrass.m1 <- drm(rootl ~ conc, data = ryegrass, fct = LL2.5())