Learn R Programming

drc (version 4.0-0)

PR: Expected or predicted response

Description

The function returns the expected or predicted response for specified dose values.

Usage

PR(object, xVec, ...)

Value

A numeric vector of predicted values or possibly a matrix of predicted values and corresponding standard errors.

Arguments

object

object of class drc obtaining fitting a dose-response model.

xVec

numeric vector of dose values.

...

additional arguments to be supplied to predict.drc. No effect at the moment.

Author

Christian Ritz after a suggestion from Andrew Kniss.

Details

This function is a convenience function for easy access to predicted values.

See Also

Predictions can also be obtained using predict.drc.

Examples

Run this code

ryegrass.m1 <- drm(ryegrass, fct = LL.4())
PR(ryegrass.m1, c(5, 10))

ryegrass.m2 <- drm(ryegrass, fct = LL2.4())
PR(ryegrass.m2, c(5, 10))

spinach.m1 <- drm(SLOPE~DOSE, CURVE, data=spinach, fct = LL.4())
PR(spinach.m1, c(5, 10))

Run the code above in your browser using DataLab