Skip to contents

Four-parameter u-shaped CRS hormesis model with lower limit fixed at 0 and alpha=0.5.

Usage

UCRS.4b(names = c("b", "d", "e", "f"), ...)

Arguments

names

a vector of character strings giving the names of the parameters.

...

additional arguments passed to ucedergreen.

Value

A list (see ucedergreen).