Four-parameter u-shaped CRS hormesis model with lower limit fixed at 0 and alpha=0.25.
Usage
UCRS.4c(names = c("b", "d", "e", "f"), ...)Arguments
- names
a vector of character strings giving the names of the parameters.
- ...
additional arguments passed to
ucedergreen.
Value
A list (see ucedergreen).