Learn R Programming

drc (version 4.0-0)

W1.2: The two-parameter Weibull functions

Description

'W1.2' is the two-parameter Weibull function where the lower limit is fixed at 0 and the upper limit is fixed at 1, mostly suitable for binomial/quantal responses.

Usage

W1.2(upper = 1, fixed = c(NA, NA), names = c("b", "e"), ...)
  
  W2.2(upper = 1, fixed = c(NA, NA), names = c("b", "e"), ...)

Value

See weibull1.

Arguments

upper

numeric value. The fixed, upper limit in the model. Default is 1.

fixed

numeric vector. Specifies which parameters are fixed and at what value they are fixed. NAs for parameter that are not fixed.

names

a vector of character strings giving the names of the parameters. The default is reasonable.

...

additional arguments to be passed from the convenience functions.

Author

Christian Ritz

Details

The two-parameter Weibull type 1 model is given by the expression $$ f(x) = \exp(-\exp(b(\log(x)-\log(e)))).$$

The function is asymmetric about the inflection point, that is the parameter \(\exp(e)\).

See Also

Related functions are W1.3, W1.4, weibull1 and weibull2.

Examples

Run this code

## Fitting a two-parameter Weibull model
earthworms.m1 <- drm(number/total~dose, weights = total,
data = earthworms, fct = W1.2(), type = "binomial")

summary(earthworms.m1)

Run the code above in your browser using DataLab