powered by
'W1.3' and W2.3 provide the three-parameter Weibull function, self starter function and names of the parameters.
W2.3
'W1.3u' and 'W2.3u' provide three-parameter Weibull function where the upper limit is equal to 1, mainly for use with binomial/quantal response.
W1.3(fixed = c(NA, NA, NA), names = c("b", "d", "e"), ...) W2.3(fixed = c(NA, NA, NA), names = c("b", "d", "e"), ...) W2x.3(fixed = c(NA, NA, NA), names = c("d", "e", "t0"), ...) W1.3u(upper = 1, fixed = c(NA, NA, NA), names = c("b", "c", "e"), ...) W2.3u(upper = 1, fixed = c(NA, NA, NA), names = c("b", "c", "e"), ...)
See weibull1.
weibull1
numeric value. The fixed, upper limit in the model. Default is 1.
numeric vector. Specifies which parameters are fixed and at what value they are fixed. NAs for parameter that are not fixed.
a vector of character strings giving the names of the parameters. The default is reasonable.
additional arguments to be passed from the convenience functions.
Christian Ritz
The three-parameter Weibull type 1 model is given by the expression $$ f(x) = 0 + (d-0)\exp(-\exp(b(\log(x)-\log(e)))).$$
The model function is asymmetric about the inflection point, which is the parameter \(\exp(e)\).
The three-parameter Weibull type 1 model with upper limit 1 is given by the expression $$ f(x) = 0 + (1-0)\exp(-\exp(b(\log(x)-\log(e)))).$$
Related functions are W1.4 and weibull1.
W1.4
## Fitting a three-parameter Weibull model ryegrass.m1 <- drm(rootl ~ conc, data = ryegrass, fct = W1.3()) ryegrass.m1
Run the code above in your browser using DataLab