Skip to contents

A three-parameter Weibull type 1 model with the upper limit fixed (default 1).

Usage

W1.3u(upper = 1, fixed = c(NA, NA, NA), names = c("b", "c", "e"), ...)

Arguments

upper

numeric value giving the fixed upper limit. The default is 1.

fixed

numeric vector of length 3. Specifies which parameters are fixed and at what value. Use NA for parameters that are not fixed.

names

character vector of length 3 giving the names of the parameters. The default is c("b", "c", "e").

...

additional arguments passed to weibull1, most notably method (a character string: "1" (default), "2", "3", or "4") which selects the self-starter method for obtaining starting values. See weibull1 for details.

Value

A list of class Weibull-1 containing the nonlinear function, self starter function, and parameter names.

Details

The model is given by the expression $$f(x) = c + (upper - c) \exp(-\exp(b(\log(x) - \log(e))))$$

This is a special case of the four-parameter Weibull type 1 model where the upper limit is fixed at a specified value.

See also