Skip to contents

A three-parameter Weibull type 2 model with lag time, where b is fixed at 1 and c is fixed at 0. This is a convenience wrapper around weibull2x.

Usage

W2x.3(fixed = c(NA, NA, NA), names = c("d", "e", "t0"), ...)

Arguments

fixed

numeric vector of length 3. Specifies which parameters are fixed and at what value. Use NA for parameters that should be estimated (default is c(NA, NA, NA)).

names

character vector of length 3 giving the names of the parameters (default is c("d", "e", "t0")).

...

additional arguments passed to weibull2x.

Value

A list of class "Weibull-2" containing the nonlinear function, self starter function, and parameter names.

See also

Examples

spinach.m1 <- drm(SLOPE ~ DOSE, data = spinach, fct = W2x.3())
summary(spinach.m1)
#> 
#> Model fitted: Weibull (type 2) with lower limit at 0 (3 parms)
#> 
#> Parameter estimates:
#> 
#>                 Estimate Std. Error t-value   p-value    
#> d:(Intercept)   0.827617   0.067677  12.229 < 2.2e-16 ***
#> e:(Intercept)   0.008972        NaN     NaN       NaN    
#> t0:(Intercept) -0.135527        NaN     NaN       NaN    
#> ---
#> Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
#> 
#> Residual standard error:
#> 
#>  0.6934874 (102 degrees of freedom)