Learn R Programming

drc (version 4.0-0)

algae: Volume of algae as function of increasing concentrations of a herbicide

Description

Dataset from an experiment exploring the effect of increasing concentrations of a herbicide on the volume of the treated algae.

Usage

data(algae)

Arguments

Format

A data frame with 14 observations on the following 2 variables.

conc

a numeric vector of concentrations.

vol

a numeric vector of response values, that is relative change in volume.

Details

This datasets requires a cubic root transformation in order to stabilise the variance.

Examples

Run this code

algae.m1 <- drm(vol ~ conc, data = algae, fct = LL.3())
summary(algae.m1)

algae.m2 <- boxcox(algae.m1)
summary(algae.m2)

Run the code above in your browser using DataLab