Learn R Programming

drc (version 4.0-0)

backfit: Calculation of backfit values from a fitted dose-response model

Description

By inverse regression backfitted dose values are calculated for the mean response per dose.

Usage

backfit(drcObject)

Value

Two columns with the original dose values and the corresponding backfitted values using the fitted dose-response model. For extreme dose values (e.g., high dose ) the backfitted values may not be well-defined (see the example below).

Arguments

drcObject

an object of class 'drc'.

Author

Christian Ritz after a suggestion from Keld Sorensen.

References

??

See Also

A related function is ED.drc.

Examples

Run this code

ryegrass.LL.4 <- drm(rootl~conc, data=ryegrass, fct=LL.4())

backfit(ryegrass.LL.4)

Run the code above in your browser using DataLab