bcl3 is an alias for BC.4.
Arguments
- fixed
numeric vector of length 4 specifying fixed parameters (NAs for free parameters).
- names
a vector of character strings giving the names of the parameters.
- ...
additional arguments passed to
braincousens.
bcl3 is an alias for BC.4.
numeric vector of length 4 specifying fixed parameters (NAs for free parameters).
a vector of character strings giving the names of the parameters.
additional arguments passed to braincousens.