bcl4 is an alias for BC.5.
Arguments
- fixed
numeric vector of length 5 specifying fixed parameters (NAs for free parameters).
- names
a vector of character strings giving the names of the parameters.
- ...
additional arguments passed to
braincousens.
bcl4 is an alias for BC.5.
numeric vector of length 5 specifying fixed parameters (NAs for free parameters).
a vector of character strings giving the names of the parameters.
additional arguments passed to braincousens.