Learn R Programming

drc (version 4.0-0)

bread.drc: Bread and meat for the sandwich

Description

Bread and meat for the sandwich estimator of the variance-covariance.

Usage

# S3 method for drc
bread(x, ...)

# S3 method for drc estfun(x, ...)

Arguments

Value

The unscaled hessian is returned by bread, whereas estfun

returns the estimating function evaluated at the data and the parameter estimates.

By default no clustering is assumed, corresponding to robust standard errors under independence. If a cluster variable is provided the log likelihood contributions provided by estfun

are summed up for each cluster.

Details

The details are provided by Zeileis (2006).

References

Zeileis, A. (2006) Object-oriented Computation of Sandwich Estimators, J. Statist. Software 16, Issue 9.

Examples

Run this code

## The lines below requires that the packages
## 'lmtest' and 'sandwich' are installed
# library(lmtest)
# library(sandwich)

# ryegrass.m1<-drm(rootl ~ conc, data = ryegrass, fct = LL.4())

# Standard summary output
# coeftest(ryegrass.m1)  

# Output with robust standard errors
# coeftest(ryegrass.m1, vcov = sandwich)

Run the code above in your browser using DataLab