Learn R Programming

drc (version 4.0-0)

comped: Comparison of effective dose values

Description

Comparison of a pair of effective dose values from independent experiments where only the estimates and their standard errors are reported.

Usage

comped(est, se, log = TRUE, interval = TRUE, operator = c("-", "/"), 
  level = 0.95, df = NULL)

Value

A matrix with the estimated difference or ratio and the associated standard error and the resulting confidence interval (unless not requested).

Arguments

est

a numeric vector of length 2 containing the two estimated ED values

se

a numeric vector of length 2 containing the two standard errors

log

logical indicating whether or not estimates and standard errors are on log scale

interval

logical indicating whether or not a confidence interval should be returned

operator

character string taking one of the two values "-" (default) or "/" corresponding to a comparison based on the difference or the ratio.

level

numeric value giving the confidence level

df

numeric value specifying the degrees of freedom for the percentile used in the confidence interval (optional)

Author

Christian Ritz

Details

The choice "/" for the argument operator and FALSE for log will result in estimation of a socalled relative potency (sometimes also called a selectivity index).

The combination TRUE for log and "/" for operator only influences the confidence interval, that is no ratio is calculated based on logarithm-transformed effective dose values.

By default confidence interval relies on percentiles in the normal distribution.

In case the entire dataset is available the functions drm and (subsequently) EDcomp should be used instead.

References

Wheeler, M. W. and Park, R. M. and Bailer, A. J. (2006) Comparing median lethal concentration values using confidence interval overlap or ratio tests, Environmental Toxicology and Chemistry, 25, 1441--1441.

See Also

The function ED.drc calculates arbitrary effective dose values based on a model fit. The function EDcomp calculates relative potencies based on arbitrary effective dose values.

Examples

Run this code

## Fitting the model
S.alba.m1 <- boxcox(drm(DryMatter~Dose, Herbicide, data=S.alba, fct = LL.4(),
pmodels=data.frame(Herbicide,1,1,Herbicide)), method = "anova") 

## Displaying estimated ED values
ED(S.alba.m1, c(10, 90))

## Making comparisons of ED50 in two ways and for both differences and ratios
compParm(S.alba.m1, "e", "/")

comped(c(28.396147, 65.573335), c(1.874598, 5.618945), log=FALSE, operator = "/")
# similar result

compParm(S.alba.m1, "e", "-")

comped(c(28.396147, 65.573335), c(1.874598, 5.618945), log=FALSE, operator = "-")
# similar result

## Making comparisons of ED10 and ED90
comped(c(21.173, 44.718), c(11.87, 8.42), log=FALSE, operator = "/")

comped(c(21.173, 44.718), c(11.87, 8.42), log=FALSE, operator = "/", interval = FALSE)

comped(c(21.173, 44.718), c(11.87, 8.42), log=FALSE, operator = "-")

Run the code above in your browser using DataLab