| drmc | R Documentation |
Set control arguments in the control argument in the function 'drm'.
drmc(constr = FALSE, errorm = TRUE, maxIt = 500, method="BFGS",
noMessage = FALSE, relTol = 1e-07, rmNA=FALSE, useD = FALSE,
trace = FALSE, otrace = FALSE, warnVal = -1, dscaleThres = 1e-15, rscaleThres = 1e-15,
conCheck = TRUE)
constr |
logical. If TRUE optimisation is constrained, only yielding non-negative parameters. |
errorm |
logical specifying whether failed convergence in |
maxIt |
numeric. The maximum number of iterations in the optimisation procedure. |
method |
character string. The method used in the optimisation procedure.
See |
noMessage |
logical, specifying whether or not messages should be displayed. |
relTol |
numeric. The relative tolerance in the optimisation procedure. |
rmNA |
logical. Should NAs be removed from sum of squares used for estimation? Default is FALSE (not removed). |
useD |
logical. If TRUE derivatives are used for estimation (if available). |
trace |
logical. If TRUE the trace from |
otrace |
logical. If TRUE any error message from the |
warnVal |
numeric. If equal to 0 then the warnings are stored and displayed at the end.
See under 'warn' in |
dscaleThres |
numeric value specifying the threshold for dose scaling. |
rscaleThres |
numeric value specifying the threshold for response scaling. |
conCheck |
logical, switching on/off handling of control measurements. |
A list with elements corresponding to each of the above arguments.
The use of a non-zero constant bcAdd may in some cases
make it more difficult to obtain convergence of the estimation procedure.
Christian Ritz
### Displaying the default settings
drmc()
### Using 'method' argument
model1 <- drm(ryegrass, fct = LL.4())
model2 <- drm(ryegrass, fct = LL.4(), control = drmc(method = "Nelder-Mead"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.