Model functions for fitting symmetric or skewed bell-shaped/biphasic dose-response patterns.
gaussian(fixed = c(NA, NA, NA, NA, NA), names = c("b", "c", "d", "e", "f"),
method = c("1", "2", "3", "4"), ssfct = NULL, fctName, fctText, loge = FALSE)
lgaussian(fixed = c(NA, NA, NA, NA, NA), names = c("b", "c",
"d", "e", "f"), method = c("1", "2", "3", "4"), ssfct = NULL,
fctName, fctText, loge = FALSE)The value returned is a list containing the nonlinear function, the self starter function and the parameter names.
numeric vector. Specifies which parameters are fixed and at what value they are fixed. NAs for parameter that are not fixed.
a vector of character strings giving the names of the parameters (should not contain ":"). The default is reasonable (see under 'Usage'). The order of the parameters is: b, c, d, e, f (see under 'Details').
character string indicating the self starter function to use.
a self starter function to be used.
optional character string used internally by convenience functions.
optional character string used internally by convenience functions.
logical indicating whether or not e or log(e) should be a parameter in the model. By default e is a model parameter.
Christian Ritz
Details yet to be provided.