Learn R Programming

drc (version 4.0-0)

getInitial: Showing starting values used

Description

Function for showing the starting values of the model parameters used when fitting a dose-response model

Usage

getInitial(object)

Value

A vector of starting values for the model parameters used to initialize the estimation procedure.

Arguments

object

object of class 'drc'

Author

Christian Ritz