Learn R Programming

drc (version 4.0-0)

gompertz: Mean function for the Gompertz dose-response or growth curve

Description

This function provides a very general way of specifying the mean function of the decreasing or incresing Gompertz dose-response or growth curve models.

Usage

gompertz(fixed = c(NA, NA, NA, NA), names = c("b", "c", "d", "e"), 
  method = c("1", "2", "3", "4"), ssfct = NULL,
  fctName, fctText)

Arguments

Value

The value returned is a list containing the non-linear function, the self starter function and the parameter names.

Details

The Gompertz model is given by the mean function

$$ f(x) = c + (d-c)(\exp(-\exp(b(x-e)))) $$

and it is a dose-response/growth curve on the entire real axis, that is it is not limited to non-negative values even though this is the range for most dose-response and growth data. One consequence is that the curve needs not reach the lower asymptote at dose 0.

If $$b<0$$ the mean function is increasing and it is decreasing for $$b>0$$. The decreasing Gompertz model is not a well-defined dose-response model and other dose-response models such as the Weibull models should be used instead.

Various re-parameterisations of the model are used in practice.

References

Seber, G. A. F. and Wild, C. J. (1989) Nonlinear Regression, New York: Wiley and Sons (p. 331).

See Also

The Weibull model weibull2 is closely related to the Gompertz model.