Learn R Programming

drc (version 4.0-0)

hatvalues.drc: Model diagnostics for nonlinear dose-response models

Description

Hat values (leverage values) and Cook's distance are provided for nonlinear dose-response model fits using the same formulas as in linear regression but based on the corresponding but approximate quantities available for nonlinear models.

Usage

# S3 method for drc
cooks.distance(model, ...)

# S3 method for drc hatvalues(model, ...)

Value

A vector of leverage values (hat values) or values of Cook's distance (one value per observation).

Arguments

model

an object of class 'drc'.

...

additional arguments (not used).

Author

Christian Ritz

Details

Hat values and Cook's distance are calculated using the formula given by Cook et al. (1986) and McCullagh and Nelder (1989).

The output values can be assessed in the same way as in linear regression.

References

Cook, R. D. and Tsai, C.-L. and Wei, B. C. (1986) Bias in Nonlinear Regression, Biometrika 73, 615--623.

McCullagh, P. and Nelder, J. A. (1989) Generalized Linear Models, Second edition, Chapman and Hall/CRC.

Examples

Run this code

ryegrass.LL.4 <- drm(rootl ~ conc, data = ryegrass, fct = LL.4())

hatvalues(ryegrass.LL.4)

cooks.distance(ryegrass.LL.4)

Run the code above in your browser using DataLab