Learn R Programming

drc (version 4.0-0)

isobole: Creating isobolograms

Description

'isobole' displays isobole based on EC/ED50 estimates from a log-logistic model. Additionally isoboles determined by the concentration addition model, Hewlett's model and Voelund's model can be added to the plot.

Usage

isobole(object1, object2, exchange = 1, cifactor = 2, ename = "e", 
xaxis = "100", xlab, ylab, xlim, ylim, ...)

Arguments

Value

No value is returned. Only used for the side effect: the isobologram shown.

Details

The model fits to be supplied as first and optionally second argument are obtained using mixture and drm.

References

Ritz, C. and Streibig, J. C. (2014) From additivity to synergism - A modelling perspective Synergy, 1, 22--29.