Learn R Programming

drc (version 4.0-0)

logLik.drc: Extracting the log likelihood

Description

loglik extracts the value of the log likelihood function evaluated at the parameter estimates.

Usage

# S3 method for drc
logLik(object, ...)

Value

The evaluated log likelihood as a numeric value and the corresponding degrees of freedom as well as the number of observations as attributes.

Arguments

object

an object of class 'drc'.

...

additional arguments.

Author

Christian Ritz

Examples

Run this code

## Fitting a four-parameter log-logistic model
ryegrass.m1 <- drm(rootl ~conc, data = ryegrass, fct = LL.4()) 
logLik(ryegrass.m1)

Run the code above in your browser using DataLab