Learn R Programming

drc (version 4.0-0)

modelFit: Assessing the model fit

Description

Assessing the fit of a dose-response model by means of formal significance tests.

Usage

modelFit(object, test = NULL, method = c("gof", "cum"))

Value

An object of class 'anova' which will be displayed in much the same way as an ordinary ANOVA table.

Arguments

object

object of class 'drc'

test

character string defining the test method to apply

method

character string specifying the method to be used for assessing the model fit

Author

Christian Ritz

Details

Currently two methods are available. For continuous data the clasical lack-of-fit test is applied (Bates and Watts, 1988). The test compares the dose-response model to a more general ANOVA model using an approximate F-test. For quantal data the crude goodness-of-fit test based on Pearson's statistic is used.

None of these tests are very powerful. A graphical assessment of the model fit is therefore recommended in addition to these formal significance tests.

References

Bates, D. M. and Watts, D. G. (1988) Nonlinear Regression Analysis and Its Applications, New York: Wiley and Sons (pp. 103--104).

Examples

Run this code

## Comparing the four-parameter log-logistic model 
##  to a one-way ANOVA model using an approximate F test
## in other words applying a lack-of-fit test
ryegrass.m1 <- drm(rootl ~ conc, data = ryegrass, fct = W1.4())
modelFit(ryegrass.m1)   

Run the code above in your browser using DataLab