Learn R Programming

drc (version 4.0-0)

multi2: Multistage dose-response model with quadratic terms

Description

The multistage dose-response model is a combination of log-logistic models that should be useful for describing more complex dose-response patterns.

Usage

multi2(
  fixed = c(NA, NA, NA, NA, NA), 
  names = c("b1", "b2", "b3", "c", "d"), 
  ssfct = NULL, 
  fctName, 
  fctText)

Value

The value returned is a list containing the nonlinear function, the self starter function and the parameter names.

Arguments

fixed

numeric vector specifying which parameters are fixed and at what value they are fixed. NAs are used for parameters that are not fixed.

names

a vector of character strings giving the names of the parameters (should not contain ":"). The default is reasonable (see under 'Usage').

ssfct

a self starter function to be used.

fctName

optional character string used internally by convenience functions.

fctText

optional character string used internally by convenience functions.

Author

Christian Ritz

Details

The multistage model function with quadratic terms is defined as follows

$$ f(x) = c + (d-c)\exp(-b1-b2x-b3x^2)$$

where x denotes the dose or the logarithm-transformed dose.

References

Wheeler, M. W., Bailer, A. J. (2009) Comparing model averaging with other model selection strategies for benchmark dose estimation, Environmental and Ecological Statistics, 16, 37--51.