Learn R Programming

drc (version 4.0-0)

nasturtium: Dose-response profile of degradation of agrochemical using nasturtium

Description

Estimation of the degradation profile of an agrochemical based on soil samples at depth 0-10cm from a calibration experiment.

Usage

data(nasturtium)

Arguments

Format

A data frame with 42 observations on the following 2 variables.

conc

a numeric vector of concentrations (g/ha)

weight

a numeric vector of plant weight (mg) after 3 weeks' growth

Details

It is an experiment with seven concentrations and six replicates per concentration. Nasturtium is sensitive and its weight reduces noticeable at low concentrations.

Racine-Poon (1988) suggests using a three-parameter log-logistic model.

Examples

Run this code

nasturtium.m1 <- drm(weight~conc, data=nasturtium, fct = LL.3())

modelFit(nasturtium.m1)

plot(nasturtium.m1, type = "all", log = "", xlab = "Concentration (g/ha)", ylab = "Weight (mg)")

Run the code above in your browser using DataLab