Learn R Programming

drc (version 4.0-0)

print.drc: Printing key features

Description

'print' displays brief information on an object of class 'drc'.

Usage

# S3 method for drc
print(x, ..., digits = max(3, getOption("digits") - 3))

Arguments

x

an object of class 'drc'.

...

additional arguments.

digits

an integer giving the number of digits of the parameter coefficients. Default is 3.

Author

Christian Ritz

Examples

Run this code

## Fitting a four-parameter log-logistic model
ryegrass.m1 <- drm(rootl ~conc, data = ryegrass, fct = LL.4())

## Displaying the model fit
print(ryegrass.m1)
ryegrass.m1  # gives the same output as the previous line

Run the code above in your browser using DataLab