'summary' compiles a comprehensive summary for objects of class 'drc'.
# S3 method for drc
summary(object, od = FALSE, pool = TRUE, ...)A list of summary statistics that includes parameter estimates and estimated standard errors.
an object of class 'drc'.
logical. If TRUE adjustment for over-dispersion is used.
logical. If TRUE curves are pooled. Otherwise they are not. This argument only works for models with
independently fitted curves as specified in drm.
additional arguments.
Christian Ritz