uml3a is an alias for UCRS.4a.
Usage
uml3a(names = c("b", "d", "e", "f"), ...)Arguments
- names
a vector of character strings giving the names of the parameters.
- ...
additional arguments passed to
ucedergreen.
uml3a is an alias for UCRS.4a.
uml3a(names = c("b", "d", "e", "f"), ...)a vector of character strings giving the names of the parameters.
additional arguments passed to ucedergreen.