uml3b is an alias for UCRS.4b.
Usage
uml3b(names = c("b", "d", "e", "f"), ...)Arguments
- names
a vector of character strings giving the names of the parameters.
- ...
additional arguments passed to
ucedergreen.
uml3b is an alias for UCRS.4b.
uml3b(names = c("b", "d", "e", "f"), ...)a vector of character strings giving the names of the parameters.
additional arguments passed to ucedergreen.