uml3c is an alias for UCRS.4c.
Usage
uml3c(names = c("b", "d", "e", "f"), ...)Arguments
- names
a vector of character strings giving the names of the parameters.
- ...
additional arguments passed to
ucedergreen.
uml3c is an alias for UCRS.4c.
uml3c(names = c("b", "d", "e", "f"), ...)a vector of character strings giving the names of the parameters.
additional arguments passed to ucedergreen.