uml4a is an alias for UCRS.5a.
Usage
uml4a(names = c("b", "c", "d", "e", "f"), ...)Arguments
- names
a vector of character strings giving the names of the parameters.
- ...
additional arguments passed to
ucedergreen.
uml4a is an alias for UCRS.5a.
uml4a(names = c("b", "c", "d", "e", "f"), ...)a vector of character strings giving the names of the parameters.
additional arguments passed to ucedergreen.