uml4b is an alias for UCRS.5b.
Usage
uml4b(names = c("b", "c", "d", "e", "f"), ...)Arguments
- names
a vector of character strings giving the names of the parameters.
- ...
additional arguments passed to
ucedergreen.
uml4b is an alias for UCRS.5b.
uml4b(names = c("b", "c", "d", "e", "f"), ...)a vector of character strings giving the names of the parameters.
additional arguments passed to ucedergreen.