uml4c is an alias for UCRS.5c.
Usage
uml4c(names = c("b", "c", "d", "e", "f"), ...)Arguments
- names
a vector of character strings giving the names of the parameters.
- ...
additional arguments passed to
ucedergreen.
uml4c is an alias for UCRS.5c.
uml4c(names = c("b", "c", "d", "e", "f"), ...)a vector of character strings giving the names of the parameters.
additional arguments passed to ucedergreen.