Learn R Programming

drc (version 4.0-0)

vcov.drc: Calculating variance-covariance matrix for objects of class 'drc'

Description

'vcov' returns the estimated variance-covariance matrix for the parameters in the non-linear function.

Usage

# S3 method for drc
vcov(object, ..., corr = FALSE, od = FALSE, pool = TRUE, unscaled = FALSE)

Value

A matrix of estimated variances and covariances.

Arguments

object

an object of class 'drc'.

...

additional arguments.

corr

logical. If TRUE a correlation matrix is returned.

od

logical. If TRUE adjustment for over-dispersion is used. This argument only makes a difference for binomial data.

pool

logical. If TRUE curves are pooled. Otherwise they are not. This argument only works for models with independently fitted curves as specified in drm.

unscaled

logical. If TRUE the unscaled variance-covariance is returned. This argument only makes a difference for continuous data.

Author

Christian Ritz

Examples

Run this code

## Fitting a four-parameter log-logistic model
ryegrass.m1 <- drm(rootl ~ conc, data = ryegrass, fct = LL.4())
vcov(ryegrass.m1)
vcov(ryegrass.m1, corr = TRUE)

Run the code above in your browser using DataLab