Learn R Programming

drc (version 4.0-0)

yieldLoss: Calculating yield loss parameters

Description

Calculation of parameters in the re-parameterization of the Michaelis-Menten model that is commonly used to assess yield loss (the rectangular hyperbola model)

Usage

yieldLoss(object, interval = c("none", "as"), level = 0.95, display = TRUE)

Value

For each of the two parameters, a matrix with two or more columns, containing the estimates and the corresponding estimated standard errors and possibly lower and upper confidence limits.

Arguments

object

object of class 'drc

interval

character string specifying the type of confidence intervals to be supplied. The default is "none". Use "as" for asymptotically-based confidence intervals.

level

numeric. The level for the confidence intervals. The default is 0.95.

display

logical. If TRUE results are displayed. Otherwise they are not (useful in simulations).

Author

Christian Ritz

Details

The rectangular hyperbola model is a reparameterization of the Michaelis-Menten in terms of parameters \(A\) and \(I\)

$$ Y_L = \frac{Id}{1+Id/A}$$

where \(d\) denotes the weed density and \(Y_L\) the resulting yield loss.

References

Cousens, R. (1985). A simple model relating yield loss to weed density, Ann. Appl. Biol., 107, 239--252.

Examples

Run this code

## Fitting Michaelis-Menten model
met.mm.m1 <- drm(gain~dose, product, data = methionine, fct = MM.3(), 
pmodels = list(~1, ~factor(product), ~factor(product)))

## Yield loss parameters with standard errrors
yieldLoss(met.mm.m1)

## Also showing confidence intervals
yieldLoss(met.mm.m1, "as")

Run the code above in your browser using DataLab