For single mixture data, combination indices for effective doses as well as effects
may be calculated. This is an extended version of CIcomp.
Arguments
- mixProp
a numeric value between 0 and 1 specifying the mixture proportion/ratio.
- modelList
a list containing 3 model fits using
drm: the mixture model fit first, followed by the 2 pure substance model fits.- EDvec
a numeric vector of effect levels (percentages between 0 and 100).
- EDonly
logical. If TRUE, only combination indices for effective doses are calculated.
Value
A list with components Effx, Effy (unless EDonly = TRUE),
CAx, CAy (unless EDonly = TRUE), and EDvec.