A six-parameter extension of the Cedergreen-Ritz-Streibig model for describing hormesis, where the alpha parameter is estimated rather than fixed.
Arguments
- fixed
numeric vector. Specifies which parameters are fixed and at what value they are fixed. NAs for parameters that are not fixed.
- names
a vector of character strings giving the names of the parameters (should not contain ":").
- method
character string indicating the self starter function to use.
- ssfct
a self starter function to be used (optional).
Value
A list containing the nonlinear model function, the self starter function, and the parameter names.
Details
The model function is:
$$f(x) = c + \frac{d-c+f \exp(-1/x^g)}{1+\exp(b(\log(x)-\log(e)))}$$
This generalises the five-parameter CRS.5a model by estimating
the alpha exponent (parameter \(g\)) instead of fixing it.
Note
This function is for use with drm.