A three-parameter exponential decay model with the slope parameter b
fixed at 1.
Arguments
- fixed
numeric vector of length 3. Specifies which parameters are fixed and at what value. Use
NAfor parameters that are not fixed.- names
character vector of length 3 giving the names of the parameters. The default is
c("c", "d", "e").- ...
additional arguments passed to
weibull1, most notablymethod(a character string:"1"(default),"2","3", or"4") which selects the self-starter method for obtaining starting values. Seeweibull1for details.
Value
A list of class Weibull-1 containing the nonlinear function,
self starter function, and parameter names.
Details
The model is given by the expression $$f(x) = c + (d - c) \exp(-x/e)$$
This is a special case of the Weibull type 1 model
(weibull1) with the slope fixed at 1.
References
Seber, G. A. F. and Wild, C. J. (1989) Nonlinear Regression, New York: Wiley & Sons (pp. 338–339).
Examples
ryegrass.m1 <- drm(rootl ~ conc, data = ryegrass, fct = EXD.3())