A three-parameter logistic model with the lower limit fixed at 0, given by $$f(x) = \frac{d}{1 + \exp(b(x - e))}$$
Arguments
- fixed
numeric vector of length 3. Specifies which parameters are fixed and at what value they are fixed.
NAindicates that the corresponding parameter is not fixed.- names
character vector of length 3 giving the names of the parameters
(b, d, e). Default isc("b", "d", "e").- ...
additional arguments passed to
logistic.
Value
A list of class "Boltzmann" containing the nonlinear function,
self starter function, and parameter names.
Examples
ryegrass.m1 <- drm(rootl ~ conc, data = ryegrass, fct = L.3())