powered by
'LL.5' and 'LL2.5' provide the five-parameter log-logistic function, self starter function and names of the parameters.
LL.5(fixed = c(NA, NA, NA, NA, NA), names = c("b", "c", "d", "e", "f"), ...) l5(fixed = c(NA, NA, NA, NA, NA), names = c("b", "c", "d", "e", "f"), ...) LL2.5(fixed = c(NA, NA, NA, NA, NA), names = c("b", "c", "d", "e", "f"), ...)
l5(fixed = c(NA, NA, NA, NA, NA), names = c("b", "c", "d", "e", "f"), ...) LL2.5(fixed = c(NA, NA, NA, NA, NA), names = c("b", "c", "d", "e", "f"), ...)
See llogistic.
llogistic
The five-parameter logistic function is given by the expression $$ f(x) = c + \frac{d-c}{(1+\exp(b(\log(x)-\log(e))))^f}$$
or in another parameterisation $$ f(x) = c + \frac{d-c}{(1+\exp(b(\log(x)-e)))^f}$$
The function is asymmetric for \(f\) different from 1.
Finney, D. J. (1979) Bioassay and the Practise of Statistical Inference, Int. Statist. Rev., 47, 1--12.
Related functions are LL.4 and LL.3.
LL.4
LL.3
ryegrass.m1 <- drm(rootl ~ conc, data = ryegrass, fct = LL.5()) summary(ryegrass.m1)
Run the code above in your browser using DataLab