Three-Parameter Log-Logistic Model with log(ED50) and Lower Limit at 0
Source:R/llogistic2.R
LL2.3.RdA three-parameter log-logistic model where the lower limit is fixed at 0.
The estimated parameters are the slope b, the upper limit d,
and the log(ED50) e.
Arguments
- fixed
numeric vector of length 3. Specifies which parameters are fixed and at what value. Use
NAfor parameters that should be estimated.- names
character vector of length 3 giving the names of the parameters
b,d, ande.- ...
additional arguments passed to
llogistic2.
Value
A list of class "llogistic" with the nonlinear function,
self-starter, and related components.
Examples
ryegrass.m1 <- drm(rootl ~ conc, data = ryegrass, fct = LL2.3())