Three-Parameter Log-Logistic Model with log(ED50) and Fixed Upper Limit
Source:R/llogistic2.R
LL2.3u.RdA three-parameter log-logistic model where the upper limit is fixed at a
specified value (default 1). The estimated parameters are the slope b,
the lower limit c, and the log(ED50) e.
Arguments
- upper
numeric value giving the fixed upper limit. Defaults to 1.
- fixed
numeric vector of length 3. Specifies which parameters are fixed and at what value. Use
NAfor parameters that should be estimated.- names
character vector of length 3 giving the names of the parameters
b,c, ande.- ...
additional arguments passed to
llogistic2.
Value
A list of class "llogistic" with the nonlinear function,
self-starter, and related components.