Returns the expected or predicted response for specified dose values. This is a convenience function for easy access to predicted values.
Arguments
- object
object of class
drcobtained from fitting a dose-response model.- xVec
numeric vector of dose values.
- ...
additional arguments passed to
predict.drc.
Value
A numeric vector of predicted values or possibly a matrix of predicted values and corresponding standard errors.