A two-parameter Weibull type 1 model with the lower limit fixed at 0 and the upper limit fixed at a specified value (default 1).
Arguments
- upper
numeric value giving the fixed upper limit. The default is 1.
- fixed
numeric vector of length 2. Specifies which parameters are fixed and at what value. Use
NAfor parameters that are not fixed.- names
character vector of length 2 giving the names of the parameters. The default is
c("b", "e").- ...
additional arguments passed to
weibull1, most notablymethod(a character string:"1"(default),"2","3", or"4") which selects the self-starter method for obtaining starting values. Seeweibull1for details.
Value
A list of class Weibull-1 containing the nonlinear function,
self starter function, and parameter names.
Details
The model is given by the expression $$f(x) = upper \exp(-\exp(b(\log(x) - \log(e))))$$
This is mostly used for binomial/quantal responses.
Examples
earthworms.m1 <- drm(number/total ~ dose, weights = total,
data = earthworms, fct = W1.2(), type = "binomial")