A three-parameter Weibull type 1 model with the lower limit fixed at 0.
Arguments
- fixed
numeric vector of length 3. Specifies which parameters are fixed and at what value. Use
NAfor parameters that are not fixed.- names
character vector of length 3 giving the names of the parameters. The default is
c("b", "d", "e").- ...
additional arguments passed to
weibull1, most notablymethod(a character string:"1"(default),"2","3", or"4") which selects the self-starter method for obtaining starting values. Seeweibull1for details.
Value
A list of class Weibull-1 containing the nonlinear function,
self starter function, and parameter names.
Details
The model is given by the expression $$f(x) = d \exp(-\exp(b(\log(x) - \log(e))))$$
This is a special case of the four-parameter Weibull type 1 model where the lower limit is fixed at 0.
Examples
ryegrass.m1 <- drm(rootl ~ conc, data = ryegrass, fct = W1.3())