Skip to contents

A four-parameter Weibull type 1 model.

Usage

W1.4(fixed = c(NA, NA, NA, NA), names = c("b", "c", "d", "e"), ...)

w4(fixed = c(NA, NA, NA, NA), names = c("b", "c", "d", "e"), ...)

Arguments

fixed

numeric vector of length 4. Specifies which parameters are fixed and at what value. Use NA for parameters that are not fixed.

names

character vector of length 4 giving the names of the parameters. The default is c("b", "c", "d", "e").

...

additional arguments passed to weibull1, most notably method (a character string: "1" (default), "2", "3", or "4") which selects the self-starter method for obtaining starting values. See weibull1 for details.

Value

A list of class Weibull-1 containing the nonlinear function, self starter function, and parameter names.

Details

The model is given by the expression $$f(x) = c + (d - c) \exp(-\exp(b(\log(x) - \log(e))))$$

References

Seber, G. A. F. and Wild, C. J. (1989) Nonlinear Regression, New York: Wiley & Sons (pp. 338–339).

Ritz, C. (2009) Towards a unified approach to dose-response modeling in ecotoxicology. Environ Toxicol Chem, 29, 220–229.

See also

Examples

terbuthylazin.m1 <- drm(rgr ~ dose, data = terbuthylazin, fct = W1.4())