backfit: Calculation of backfit values from a fitted dose-response model
Description
By inverse regression backfitted dose values are calculated for the mean response per dose.
Usage
backfit(drcObject)
Value
Two columns with the original dose values and the corresponding backfitted values using the fitted dose-response model.
For extreme dose values (e.g., high dose ) the backfitted values may not be well-defined (see the example below).
Arguments
drcObject
an object of class 'drc'.
Author
Christian Ritz after a suggestion from Keld Sorensen.