Provides the Cedergreen-Ritz-Streibig function, a five-parameter model
for describing dose-response curves that exhibit hormesis (a stimulatory or
beneficial effect at low doses). This function generates a model object suitable
for use with non-linear regression functions like drm.
Arguments
- fixed
A numeric vector of length 5 specifying any parameters to be held fixed during the estimation. The order is
c(b, c, d, e, f). UseNAfor parameters that should be estimated. The default is to estimate all parameters.- names
A character vector of length 5 providing names for the parameters. The default is
c("b", "c", "d", "e", "f").- method
A character string specifying the method for the self-starter function to use for finding initial parameter values. Options are
"loglinear","anke","method3", and"normolle". This is only used ifssfctisNULL.- ssfct
A custom self-starter function. If
NULL(the default), a self-starter is automatically generated by callingcedergreen.ssfwith the specifiedmethod,fixed, andalphaarguments.- alpha
A mandatory numeric value specifying the fixed shape parameter \(\alpha\). The function will stop if this is not provided.
- fctName
An optional character string to name the function object.
- fctText
An optional character string providing a descriptive text for the model.
Value
A list of class mllogistic, containing the model function (fct),
the self-starter function (ssfct), parameter names (names), and other
components required for use with modeling functions like drm.
Details
The Cedergreen-Ritz-Streibig model is defined by the following equation: $$f(x) = c + \frac{d - c + f \exp(-1/x^{\alpha})}{1 + \exp(b(\log(x) - \log(e)))}$$ The parameter \(f\) determines the size of the hormetic effect (stimulation). If \(f=0\), the model simplifies to the standard four-parameter log-logistic model. The parameter \(\alpha\) is a shape parameter that must be specified by the user.
See also
drm for model fitting, and cedergreen.ssf for the
underlying self-starter function.
Examples
dose <- c(0, 0.1, 0.5, 1, 5, 10, 20)
response <- c(100, 102, 95, 80, 40, 25, 20)
my_data <- data.frame(dose = dose, response = response)
model_fit <- drm(response ~ dose, data = my_data,
fct = cedergreen(alpha = 0.5))
summary(model_fit)
#>
#> Model fitted: Cedergreen-Ritz-Streibig (5 parms)
#>
#> Parameter estimates:
#>
#> Estimate Std. Error t-value p-value
#> b:(Intercept) 1.1619 0.2153 5.3965 0.0326651 *
#> c:(Intercept) 13.5774 4.5892 2.9585 0.0977776 .
#> d:(Intercept) 101.4210 2.0399 49.7190 0.0004043 ***
#> e:(Intercept) 1.3820 1.1363 1.2162 0.3479717
#> f:(Intercept) 72.5388 126.6937 0.5726 0.6247324
#> ---
#> Signif. codes: 0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
#>
#> Residual standard error:
#>
#> 2.513311 (2 degrees of freedom)