- constr
logical. If TRUE optimisation is constrained, only yielding non-negative parameters.
- errorm
logical specifying whether failed convergence in drm should result
in an error or only a warning.
- maxIt
numeric. The maximum number of iterations in the optimisation procedure.
- method
character string. The method used in the optimisation procedure.
See optim for available methods.
- noMessage
logical, specifying whether or not messages should be displayed.
- relTol
numeric. The relative tolerance in the optimisation procedure.
- rmNA
logical. Should NAs be removed from sum of squares used for estimation?
Default is FALSE (not removed).
- useD
logical. If TRUE derivatives are used for estimation (if available).
- trace
logical. If TRUE the trace from optim is displayed.
- otrace
logical. If TRUE any error message from the optim call is suppressed.
- warnVal
numeric. If equal to 0 then the warnings are stored and displayed at the end.
See under 'warn' in options. The default results in suppression of warnings.
- dscaleThres
numeric value specifying the threshold for dose scaling.
- rscaleThres
numeric value specifying the threshold for response scaling.
- conCheck
logical, switching on/off handling of control measurements.