Evaluates the estimating function (the "meat") for the sandwich estimator of the variance-covariance matrix for objects of class 'drc'.
Value
The estimating function evaluated at the data and the parameter estimates. By default no clustering is assumed, corresponding to robust standard errors under independence.
References
Zeileis, A. (2006) Object-oriented Computation of Sandwich Estimators, J. Statist. Software, 16, Issue 9.
Examples
## The lines below requires that the packages
## 'lmtest' and 'sandwich' are installed
# library(lmtest)
# library(sandwich)
# ryegrass.m1<-drm(rootl ~ conc, data = ryegrass, fct = LL.4())
# Standard summary output
# coeftest(ryegrass.m1)
# Output with robust standard errors
# coeftest(ryegrass.m1, vcov = sandwich)