Model function for specifying dose-response models that are a combination of a logistic model and an appropriate class of fractional polynomials.
Arguments
- p1
numeric denoting the negative power of log(dose+1) in the fractional polynomial.
- p2
numeric denoting the positive power of log(dose+1) in the fractional polynomial.
- fixed
numeric vector. Specifies which parameters are fixed and at what value they are fixed. NAs for parameters that are not fixed.
- names
a vector of character strings giving the names of the parameters (should not contain ":"). The order of the parameters is: b, c, d, e.
- method
character string indicating the self starter function to use.
- ssfct
a self starter function to be used.
- fctName
optional character string used internally by convenience functions.
- fctText
optional character string used internally by convenience functions.
Details
The fractional polynomial dose-response models introduced by Namata et al. (2008) are implemented using the logistic model as base.