A four-parameter dose-response model derived from the cumulative distribution function of the gamma distribution. Only suitable for increasing dose-response data.
Arguments
- fixed
numeric vector specifying which parameters are fixed and at what value they are fixed. NAs are used for parameters that are not fixed.
- names
a vector of character strings giving the names of the parameters (should not contain ":"). The default is reasonable.
- fctName
optional character string used internally by convenience functions.
- fctText
optional character string used internally by convenience functions.
Details
Following Wheeler and Bailer (2009) the model function is:
$$f(x) = c + (d-c) \cdot \mathrm{pgamma}(b \cdot x, e, 1)$$