powered by
Function for showing the starting values of the model parameters used when fitting a dose-response model
getInitial(object)
A vector of starting values for the model parameters used to initialize the estimation procedure.
object of class 'drc'
Christian Ritz