Dose-response profile of degradation of agrochemical using lepidium
lepidium.RdEstimation of the degradation profile of an agrochemical based on soil samples at depth 0-10cm from a calibration experiment.
Usage
data(lepidium)Format
A data frame with 42 observations on the following 2 variables.
conca numeric vector of concentrations (g/ha)
weighta numeric vector of plant weight (g) after 3 weeks' growth
Details
It is an experiment with seven concentrations and six replicates per concentration. Lepidium is rather robust as it only responds to high concentrations.