A five-parameter log-logistic model where the ED50 is parameterised on the
log scale. The mean function is:
$$f(x) = c + \frac{d - c}{(1 + \exp(b(\log(x) - e)))^f}$$
where e is the logarithm of the ED50 (not exponentiated).
Arguments
- fixed
numeric vector of length 5. Specifies which parameters are fixed and at what value. Use
NAfor parameters that should be estimated.- names
character vector of length 5 giving the names of the parameters
b,c,d,e, andf.- ss
character string indicating the self-starter version to use. One of
"1"(default),"2", or"3".- ssfct
optional self-starter function. If provided, overrides the built-in self-starter selected by
ss.- fctName
optional character string specifying the name of the function.
- fctText
optional character string providing a short description of the function.