logLik extracts the value of the log likelihood function evaluated
at the parameter estimates.
Usage
# S3 method for class 'drc'
logLik(object, ...)logLik extracts the value of the log likelihood function evaluated
at the parameter estimates.
# S3 method for class 'drc'
logLik(object, ...)