powered by
loglik extracts the value of the log likelihood function evaluated at the parameter estimates.
loglik
# S3 method for drc logLik(object, ...)
The evaluated log likelihood as a numeric value and the corresponding degrees of freedom as well as the number of observations as attributes.
an object of class 'drc'.
additional arguments.
Christian Ritz
## Fitting a four-parameter log-logistic model ryegrass.m1 <- drm(rootl ~conc, data = ryegrass, fct = LL.4()) logLik(ryegrass.m1)
Run the code above in your browser using DataLab