A five-parameter multistage dose-response model useful for describing more complex dose-response patterns.
Arguments
- fixed
numeric vector specifying which parameters are fixed and at what value they are fixed. NAs are used for parameters that are not fixed.
- names
a vector of character strings giving the names of the parameters (should not contain ":"). The default is reasonable.
- ssfct
a self starter function to be used.
- fctName
optional character string used internally by convenience functions.
- fctText
optional character string used internally by convenience functions.
Details
The multistage model function with quadratic terms is:
$$f(x) = c + (d-c)\exp(-b1 - b2 x - b3 x^2)$$
where x denotes the dose or the logarithm-transformed dose.