nasturtium: Dose-response profile of degradation of agrochemical using nasturtium
Description
Estimation of the degradation profile of an agrochemical based on soil samples at depth 0-10cm
from a calibration experiment.
Usage
data(nasturtium)
Arguments
Format
A data frame with 42 observations on the following 2 variables.
conc
a numeric vector of concentrations (g/ha)
weight
a numeric vector of plant weight (mg) after 3 weeks' growth
Details
It is an experiment with seven concentrations and six replicates per concentration. Nasturtium
is sensitive and its weight reduces noticeable at low concentrations.
Racine-Poon (1988) suggests using a three-parameter log-logistic model.