A ten-parameter dose-response model combining three log-logistic components,
extending the two-phase model (twophase) for describing even more
complex dose-response patterns.
Arguments
- fixed
numeric vector specifying which parameters are fixed and at what value they are fixed. NAs are used for parameters that are not fixed.
- names
a vector of character strings giving the names of the parameters (should not contain ":"). The default is reasonable.
- fctName
optional character string used internally by convenience functions.
- fctText
optional character string used internally by convenience functions.