ucedergreen provides a very general way of specifying the Cedergreen-Ritz-Streibig
modified log-logistic model for describing u-shaped hormesis, under various constraints on the parameters.
Arguments
- fixed
A numeric vector of length 5 specifying any parameters to be held fixed during the estimation. The order is
c(b, c, d, e, f). UseNAfor parameters that should be estimated. The default is to estimate all parameters.- names
A character vector of length 5 providing names for the parameters. The default is
c("b", "c", "d", "e", "f").- method
A character string specifying the method for the self-starter function to use for finding initial parameter values. Options are
"loglinear","anke","method3", and"normolle". This is only used ifssfctisNULL.- ssfct
A custom self-starter function. If
NULL(the default), a self-starter is automatically generated by callingcedergreen.ssfwith the specifiedmethod,fixed, andalphaarguments.- alpha
A mandatory numeric value specifying the fixed shape parameter \(\alpha\). The function will stop if this is not provided.
- fctName
An optional character string to name the function object.
- fctText
An optional character string providing a descriptive text for the model.
Value
A list of class "UCRS", containing the model function (fct),
the self-starter function (ssfct), parameter names (names), and other
components required for use with modeling functions like drm.
Details
The u-shaped model is given by the expression $$f(x) = c + d - \frac{d-c+f \exp(-1/x^{\alpha})}{1+\exp(b(\log(x)-\log(e)))}$$
References
Cedergreen, N. and Ritz, C. and Streibig, J. C. (2005) Improved empirical models describing hormesis, Environmental Toxicology and Chemistry 24, 3166–3172.