powered by
'vcov' returns the estimated variance-covariance matrix for the parameters in the non-linear function.
# S3 method for drc vcov(object, ..., corr = FALSE, od = FALSE, pool = TRUE, unscaled = FALSE)
A matrix of estimated variances and covariances.
an object of class 'drc'.
additional arguments.
logical. If TRUE a correlation matrix is returned.
logical. If TRUE adjustment for over-dispersion is used. This argument only makes a difference for binomial data.
logical. If TRUE curves are pooled. Otherwise they are not. This argument only works for models with independently fitted curves as specified in drm.
drm
logical. If TRUE the unscaled variance-covariance is returned. This argument only makes a difference for continuous data.
Christian Ritz
## Fitting a four-parameter log-logistic model ryegrass.m1 <- drm(rootl ~ conc, data = ryegrass, fct = LL.4()) vcov(ryegrass.m1) vcov(ryegrass.m1, corr = TRUE)
Run the code above in your browser using DataLab