Provides a general framework for the four-parameter Weibull type 2 model given by the equation $$f(x) = c + (d - c)(1 - \exp(-\exp(b(\log(x) - \log(e)))))$$
Arguments
- fixed
numeric vector of length 4, specifying fixed parameters (use
NAfor parameters that should be estimated).- names
character vector of length 4 giving the names of the parameters (default
c("b", "c", "d", "e")).- method
character string indicating the self starter method to use for obtaining starting values. One of
"1"(default),"2","3", or"4". See Details.- ssfct
a self starter function. If
NULL(default), a built-in self starter is used based onmethod.- fctName
optional character string used internally for the function name.
- fctText
optional character string used internally for the function description.
Value
A list containing the nonlinear function, self starter function,
and parameter names. The list has class "Weibull-2".
Details
The method argument determines how starting values for the parameters
b and e are estimated (the starting values for c and
d are always based on the range of the response values). Four methods
are available:
"1"(default)Linear regression on transformed data. Applies a complementary log-log transformation to the response and a log transformation to the dose, then fits a linear regression to estimate starting values for
bande."2"Anke's procedure. Estimates
eby finding the dose at which the response crosses the midpoint betweencandd, then estimatesbas the median of back-calculated values."3"Stepwise approach. Identifies where the mean response crosses the midpoint between
canddand uses the corresponding dose as the starting value fore. The starting value forbis based on the sign of the slope at that point."4"Normolle's procedure. Uses the mean of the dose range as an initial estimate for
e, then estimatesbandeusing median-based back-calculations.